@@ -1,5 +1,6 @@
 import copy
 from fields import Field, AutoField
+from stdnet.exceptions import *
 
 def get_fields(bases, attrs):
     fields = {}
@@ -16,10 +17,16 @@ def get_fields(bases, attrs):
 
 
 class Metaclass(object):
-    '''Model metaclass contains all the information which relates the python object to
-    the database model'''
     
     def __init__(self, model, fields, abstract = False, keyprefix = None):
+        '''Model metaclass contains all the information which relates a python class to a database model. An instnace
+is initiated when registering a new model with a database backend:
+
+    * *model* a model class
+    * *fields* dictionary of field instances
+    * *abstract* if True, it represents an abstract model and no database model are created
+    * *keyprefix*
+'''
         self.abstract  = abstract
         self.keyprefix = keyprefix
         self.model     = model
@@ -27,7 +34,7 @@ class Metaclass(object):
         self.fields    = fields
         self.related   = {}
         model._meta    = self
-        if not self.abstract:
+        if not abstract:
             try:
                 pk = self.pk
             except:
@@ -49,6 +56,13 @@ class Metaclass(object):
     @property
     def pk(self):
         return self.fields['id']
+    
+    @property
+    def id(self):
+        return self.pk.value
+    
+    def has_pk(self):
+        return self.pk.value
         
     def basekey(self, *args):
         key = '%s%s' % (self.keyprefix,self.name)
@@ -63,17 +77,21 @@ class Metaclass(object):
                 field.save(commit)
         
     def delete(self):
-        '''Delete the object from the backend database'''
-        id = self.id
-        if not id:
-            return
-        # First thing Remove id form indexes
-        for name,field in self.fields.itervalues():
-            if name is not 'id':
-                field.remove(id)
-        self.pk.remove()
-        for related in self.related:
-            pass
+        '''Delete the object from the back-end database and return the number of objects removed.'''
+        if not self.has_pk():
+            raise StdNetException('Cannot delete object. It was never saved.')
+        # Gather related objects to delete
+        objs = self.related_objects()
+        T = 0
+        for obj in objs:
+            T += obj.delete()
+        return T + self.cursor.delete_object(self)
+    
+    def related_objects(self):
+        objs = []
+        for rel in self.related.itervalues():
+            objs.extend(rel.all())
+        return objs
                             
     def __deepcopy__(self, memodict):
         # We deep copy on fields and create the keys list
@@ -107,6 +125,7 @@ class DataMetaClass(type):
         return new_class
     
 
+
 def meta_options(abstract = False,
                  keyprefix = None,
                  **kwargs):
