@@ -1,6 +1,8 @@
 from copy import copy
 import time
 from stdnet.exceptions import FieldError
+from query import RelatedManager
+
 
 __all__ = ['Field',
            'AutoField',
@@ -91,6 +93,22 @@ class Field(object):
                 return meta.cursor.add_index(key, obj.id, commit, timeout = meta.timeout)
         
             self.savevalue(value)
+            
+    def delete(self):
+        '''Delete the field from the database.'''
+        meta    = self.meta
+        value   = self.get_value(self._cleanvalue())
+        if self.primary_key:
+            return meta.cursor.delete_object(obj)
+        
+        elif self.index:
+            key     = meta.basekey(name,value)
+            if self.unique:
+                return meta.cursor.add_string(key, obj.id, commit, timeout = meta.timeout)
+            elif self.ordered:
+                raise NotImplementedError
+            else:
+                return meta.cursor.add_index(key, obj.id, commit, timeout = meta.timeout)
         
     def savevalue(self, value):
         pass
@@ -120,27 +138,6 @@ class DateField(Field):
         dte = self.value
         if dte:
             return int(time.mktime(dte.timetuple()))
-
-
-
-class RelatedManager(object):
-    
-    def __init__(self, fieldname, related):
-        self.related    = related
-        self.fieldname  = fieldname
-        self.obj        = None
-        
-    def all(self):
-        if self.obj:
-            meta = self.related._meta
-            id   = meta.basekey(self.fieldname,self.obj.id)
-            data = meta.cursor.unordered_set(id)
-            hash = meta.cursor.hash(meta.basekey())
-            return hash.mget(data)
-    
-    def __deepcopy__(self, memodict):
-        # We only copy here
-        return self.__class__(self.fieldname,self.related)
         
 
 
